/*******************************************************************************
 * Copyright Actel Corporation.
 *
 * Simple test program flashing LEDs
 *
 */

#include "socParPort.h"
#include "platform.h"
#include "arm.h"

#define PUT_UINT32(addr, data)    *((volatile unsigned int *) (addr)) = (data)
#define GET_UINT32(addr, pData)   (*pData) = *((volatile unsigned int *) (addr))

/******************************************************************************/
void main( void )
{
    unsigned int switchValue;
    unsigned int i, loopCount;
    
    //The lower two control bits (otherwise unused) are connected to the top two LEDs
    unsigned int extraControlBits = 0x1;

    DisableIRQ();
    DisableFIQ();

	//Initialize the loopCount
    loopCount = 0;
    
    for (;;)
    {
       //Configure Parallel Port to accept switch inputs
       PUT_UINT32(PARALLEL_BASE_ADDR+PARALLEL_CONTROL_OFFSET, PARALLEL_CONTROL_DATA_INPUT | extraControlBits);
       //Read the switch settings through the data register location
       GET_UINT32(PARALLEL_BASE_ADDR+PARALLEL_DATA_OFFSET, &switchValue);
       //Configure Parallel Port to drive outputs
       PUT_UINT32(PARALLEL_BASE_ADDR+PARALLEL_CONTROL_OFFSET, PARALLEL_CONTROL_DATA_OUTPUT  | extraControlBits);
       //Drive the ouptuts (to LEDs) based on the switch settings
       PUT_UINT32(PARALLEL_BASE_ADDR+PARALLEL_DATA_OFFSET, switchValue & 0xFF);
  
       //Wait
       for (i = 0; i < 80000; i++ ) { } 
       
       if (loopCount++ == 3)
       {
       	    //Reset loopCount
			loopCount = 0; 
			//Toggle lower two control bits.
			//This produces the "heartbeat" on the top 2 LEDs when program is executing.
			extraControlBits = ~extraControlBits & 0x3;	
       }
    }
}

